==========
User Guide
==========

.. toctree::
   :maxdepth: 2
   :caption: Getted Started

   install
   format
   run
   report
   gui
   faq

.. toctree::
   :maxdepth: 2
   :caption: Advanced

   build
   hmm
   cli
   python
